@@ -1,10 +1,8 @@
 import click
 import os
 import os.path as op
-from glob import glob
 
 from .command import (
-    dandiset_id_option,
     dandiset_path_option,
     devel_debug_option,
     lgr,
@@ -157,7 +155,7 @@ def organize(
         # Our dumps of metadata
         metadata = load_jsonl(paths[0])
     else:
-        paths = list(find_files("\.nwb$", paths=paths))
+        paths = list(find_files(r"\.nwb$", paths=paths))
         lgr.info("Loading metadata from %d files", len(paths))
         # Done here so we could still reuse cached 'get_metadata'
         # without having two types of invocation and to guard against
